# `pip install pywxdll`
# pywxdll

A Python package for wechat dll hook 一个用于微信Dll Hook的Python库

# 起因

写微信机器人时在看大佬写的库 死活搞不懂咋发送/接受信息 所以自己写了一个

# For start

Currently writing documents, please use docker env(link: https://github.com/ChisBread/wechat-service/)

# Credits

https://github.com/ChisBread/wechat-service/

https://github.com/cixingguangming55555/wechat-bot

https://github.com/chisbread/wechat-box
